<?php
/*
 * Custom CustomModuleApi.php to improve the performance of CRUD for Lead
 * @class:  CustomModuleApi
 * @extends: ModuleApi
 */
 require_once("clients/base/api/ModuleApi.php");
 
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');

class eTrigueModuleApi extends ModuleApi
{
  /*
  * function: registerApiRest
  * description: Function used to register REST Api
  */
    public function registerApiRest()
    {
        return array(
      'create' => array(
                'reqType' => 'POST',
                'path' => array('eTrigue','<module>'),
                'pathVars' => array('eTrigue','module'),
                'method' => 'createRecords',
                'shortHelp' => 'This method creates a new records in bulk of the specified type',
                'longHelp' => 'custom/clients/base/api/help/etrigue_module_record_create_multiple_help.html',
            ),
      'retrieve' => array(
                'reqType' => 'GET',
                'path' => array('eTrigue','<module>','?'),
                'pathVars' => array('eTrigue','module','record'),
                'method' => 'retrieveRecords',
                'shortHelp' => 'Returns bulk of requested records',
        'longHelp' => 'custom/clients/base/api/help/etrigue_module_record_get_multiple_help.html',
            ),
             'update' => array(
                'reqType' => 'PUT',
                'path' => array('eTrigue','<module>','?'),
                'pathVars' => array('eTrigue','module','record'),
                'method' => 'updateRecords',
                'shortHelp' => 'This method updates multiple records of the specified type at once',
                'longHelp' => 'custom/clients/base/api/help/etrigue_module_record_put_multiple_help.html',
            ),
            'delete' => array(
                'reqType' => 'DELETE',
                'path' => array('eTrigue','<module>','?'),
                'pathVars' => array('eTrigue','module','record'),
                'method' => 'deleteRecords',
                'shortHelp' => 'This method deletes multiple requested records of the specified type',
                'longHelp' => 'custom/clients/base/api/help/etrigue_module_record_delete_multiple_help.html',
            ),
        );
    }
  /**
     * Create the lead record and optionally perform post-save actions for Convert Target & Lead from Email cases
     */
  public function createRecords($api, $args) {
    //$GLOBALS['log']->fatal('CreateRecords function is called');
    //$GLOBALS['log']->fatal($args);
    //$GLOBALS['log']->fatal(count ($args['data']));
      foreach($args['data'] as $k=>$val){
        $arguments = $args;
        foreach ($args['data'][$k]  as $key=>$value){
          $arguments[$key] = $value;
        }   
        $data_array[] = parent::createRecord($api, $arguments);       
      }
    //$GLOBALS['log']->fatal($data_array);
    return $data_array; 
  }
  /*
  * Function over-ride to retrieve more than 1 record at a time
  */
  public function retrieveRecords($api, $args) {
    //$GLOBALS['log']->fatal('retrieveRecord function is called');
    //$GLOBALS['log']->fatal($args);
    $ids_array = json_decode($args['record']);
    foreach($ids_array as $val){
      $args['record'] = $val;
      $data = array();
      try{
        $data = parent::retrieveRecord($api, $args);
      }catch(Exception $e){ //Catch All Possible Exception; most probable exception will be "SugarApiExceptionNotFound"
          $data = array(
          'id' => $val,
          'error' => 'Record not found',
        );
      }
      $data_array[] = $data;        
    } 
    return $data_array;
  }
  /*
  * Function over-ride to update more than 1 record at a time
  */
  public function updateRecords($api, $args) {
    //$GLOBALS['log']->fatal('updateRecord function is called');
    //$GLOBALS['log']->fatal($args);
    $ids_array = json_decode($args['record']);
    //$GLOBALS['log']->fatal(count($ids_array));
    foreach($ids_array as $k=>$val){
      $arguments = $args;
      $arguments['record'] = $val;  
        foreach ($args['data'][$k]  as $key=>$value){
      $arguments[$key] = $value;
      }
      $data = array();
      try{
        $data = parent::updateRecord($api,$arguments);
      }catch(Exception $e){ //Catch All Possible Exception; most probable exception will be "SugarApiExceptionNotFound"
        $data = array(
          'id' => $val,
          'error' => 'Record not found',
        );
      }
      $data_array[] = $data;        
    } 
    return $data_array;
  }
  /*
  * Function over-ride to delete more than 1 record at a time
  */
  public function deleteRecords($api, $args) {
    //$GLOBALS['log']->fatal('deleteRecord function is called');  
    //$GLOBALS['log']->fatal($args);    
    $ids_array = json_decode($args['record']);
    //$GLOBALS['log']->fatal(count($ids_array));
    foreach($ids_array as $val){
      $args['record'] = $val;
      $data = array();
      try{
        $data = parent::deleteRecord($api, $args);
      }catch(Exception $e){ //Catch All Possible Exception; most probable exception will be "SugarApiExceptionNotFound"
        $data = array(
          'id' => $val,
          'error' => 'Record not found',
        );
      }
      $data_array[] = $data;        
    } 
    //$GLOBALS['log']->fatal($data_array);  
    return $data_array;
  } 
}
