<?php
/*
 * Custom eTrigueRelateRecordApi.php to create and update related records of specific type in bulk
 * @class:  eTrigueRelateRecordApi
 * @extends: RelateRecordApi
 */
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');

require_once('clients/base/api/ModuleApi.php');
require_once('clients/base/api/RelateRecordApi.php');

class eTrigueRelateRecordApi extends RelateRecordApi {
    public function registerApiRest() {
        return array(
            'eTriguecreateRelatedRecord' => array(
                'reqType'   => 'POST',
                'path'      => array('eTrigue','<module>','?',     'link','?'),
                'pathVars'  => array('eTrigue','module',  'record','',    'link_name'),
                'method'    => 'eTriguecreateRelatedRecord',
                'shortHelp' => 'Create multiple records of Specific Module and relate it to this module',
                'longHelp'  => 'custom/clients/base/api/help/eTrigue_module_records_link_link_name_post_help.html',
            ),
      'eTriguecreateRelatedLink' => array(
                'reqType'   => 'POST',
                'path'      => array('eTrigue','<module>','link','?'        ,'?'),
                'pathVars'  => array('eTrigue','module', '',    'link_name','ids'),
                'method'    => 'eTriguecreateRelatedLink',
                'shortHelp' => 'Relates existing records to this module.',
                'longHelp'  => 'custom/clients/base/api/help/eTrigue_module_link_link_name_ids_post_help.html',
            ),
            'eTrigueupdateRelatedLink' => array(
                'reqType'   => 'PUT',
                'path'      => array('eTrigue','<module>','link','?'        ,'?'),
                'pathVars'  => array('eTrigue','module', '',    'link_name','ids'),
                'method'    => 'eTrigueupdateRelatedLink',
                'shortHelp' => 'Updates relationship specific information ',
                'longHelp'  => 'custom/clients/base/api/help/eTrigue_module_link_link_name_ids_put_help.html',
            ),
        );
    }
  /*
  Custom Function to Create Related Records in Bulk
  */
    function eTriguecreateRelatedRecord($api, $args) {
    $ids_array = json_decode($args['record']);
    $count = 0;
      foreach($args['data'] as $k=>$val){
        $arguments = $args;
        unset($arguments['data']);
        $arguments['record'] = $ids_array[$count];
        // set the data for creating linked record as arguments
        foreach ($args['data'][$k]  as $key=>$value){
          $arguments[$key] = $value;
        }  
        $data = array();
        // handle exception if parent record does not exist
        try{
          $data =parent::createRelatedRecord($api, $arguments); 
        }catch(Exception $e){ //Catch All Possible Exception; most probable exception will be "SugarApiExceptionNotFound"
          $data = array(
            'id' => $ids_array[$count],
            'error' => 'Record not found',
          );
        }       
        $data_array[] = $data;
        $count++;
      }   
    return $data_array;
    }
  /*
  Custom Function to Update Related Records of Specific Module in Bulk
  */
    function eTrigueupdateRelatedLink($api, $args) {
    $ids_array = json_decode($args["ids"]);
    foreach($ids_array as $k=>$val){
      $arguments = $args;
      unset($arguments['data']);
      $arguments['record'] = $val->sid;
      $arguments['remote_id'] = $val->rid;
      foreach ($args['data'][$k]  as $key=>$value){
        $arguments[$key] = $value;
      } 
      $data = array();    
      // handle exception if parent/child record does not exist
      try{
        $data =parent::updateRelatedLink($api, $arguments); 
      }catch(Exception $e){ //Catch All Possible Exception; most probable exception will be "SugarApiExceptionNotFound"
        $data = array(
          'source_id' => $val->sid,
          'remote_id' => $val->rid,
          'error' => 'Primary or Linked Record not found with the provided Ids',
        );
      }       
      $data_array[] = $data;    
    }   
    return $data_array;   
    }
  /*
  Custom Function to create Related link of Specific Module in Bulk
  */
  function eTriguecreateRelatedLink($api, $args) {
    $ids_array = json_decode($args["ids"]);
    foreach($ids_array as $k=>$val){
      $arguments = $args;
      unset($arguments['ids']);
      $arguments['record'] = $val->sid;
      $arguments['remote_id'] = $val->rid;
      $data = array();
      // handle exception if parent/child record does not exist
      try{
        $data = parent::createRelatedLink($api, $arguments);  
      }catch(Exception $e){ //Catch All Possible Exception; most probable exception will be "SugarApiExceptionNotFound"
        $data = array(
          'source_id' => $val->sid,
          'remote_id' => $val->rid,
          'error' => 'Primary or Linked Record not found with the provided Ids',
        );
      }       
      $data_arr[] = $data;    
    }   
    return $data_arr;   
    }
}